'use client'
import useShowToast from '@/app/hooks/useShowToast'
import { createLocationRequest } from '@/app/lib/attendance/action'
import GoogleMap from '@/components/googleMap'
import { Card } from '@chakra-ui/react'
import { AdvancedMarker, Pin } from '@vis.gl/react-google-maps'
import React, { useEffect, useState } from 'react'
import { getAttendance } from './attendance'
import { setStorage } from '@/utils/navigation'



const getMarkerIcon = (color: string) => ({
    path: 'M12 2C8.13 2 5 5.13 5 9c0 3.87 7 11 7 11s7-7.13 7-11c0-3.87-3.13-7-7-7z',
    fillColor: color,
    fillOpacity: 1,
    strokeColor: 'black',
    strokeWeight: 1,
    scale: 2.1,
});

type LatLng = {
    lat: number;
    lng: number;
};

const Location = () => {
    const showToast = useShowToast();
    const [currentLocation, setCurrentLocation] = useState<LatLng | null>(null);


    const handleSendLocation = async ({ latitude, longitude }: { latitude: number, longitude: number }) => {
        try {
            const form = {
                latitude: latitude,
                longitude: longitude,
                status: "active"
            }
            const response = await createLocationRequest(form);
            // showToast("Created!", response.message, "success");

        } catch (error: any) {
            showToast("Failed to create", error.message, "error");
        }
    };


    useEffect(() => {

        const updateLocation = () => {
            navigator.geolocation.getCurrentPosition(
                (position) => {
                    const { latitude, longitude } = position.coords;
                    console.log("Latitude is :", latitude);
                    setStorage('lat-lng', { latitude: position?.coords?.latitude, longitude: position?.coords?.longitude })
                    setCurrentLocation({ lat: latitude, lng: longitude });
                    const attendance = getAttendance()
                    attendance && handleSendLocation({ latitude, longitude })
                },
                (error) => {
                    console.error("Error fetching location", error);
                }
            );
        };

        updateLocation();

        const locationInterval = setInterval(updateLocation, 180000);

        return () => clearInterval(locationInterval);
    }, []);


    return (
        <>
            {currentLocation && (
                <Card py="15px" px="12px" gap={3}>
                    <GoogleMap
                        defaultCenter={currentLocation}
                        defaultZoom={17}
                    >
                        <AdvancedMarker
                            position={currentLocation}
                            // @ts-ignore
                            icon={getMarkerIcon(1 === 1 ? 'green' : 'red')}
                        >
                            <Pin />
                        </AdvancedMarker>
                    </GoogleMap>
                </Card>
            )}
        </>
    )
}

export default Location